function parse_result(classes, ind_classes, filename, NumStates, BinaryStates, outfile, vars, printout)

if nargin < 7
    printout = 0;
end;
fid = fopen(filename);
locBel = fread(fid,'double');
fclose(fid);

%---------------------
% Read superpixels
RPixel = [];
[j, blockstart, blockend, statestart, stateend] = getvardata(vars, 'SP', 1);
NumP = blockend - blockstart + 1;
if blockstart > 0
    RPixel = locBel(statestart:stateend);
    RPixel = reshape(RPixel,NumStates,NumP);
end;
%---------------------
%---------------------
% Read supersegments
RSeg = []; 
[j, blockstart, blockend, statestart, stateend] = getvardata(vars, 'SS', 1);
NumS = blockend - blockstart + 1;
if blockstart > 0
   RSeg = locBel(statestart:stateend);
   RSeg = reshape(RSeg,NumStates,NumS);
end;
%---------------------
%---------------------
% Read Zi
RZ = [];
[j, blockstart, blockend, statestart, stateend] = getvardata(vars, 'Z', 1);
if blockstart > 0   % check if variable exists
   RZ = locBel(statestart:stateend);
   RZ = reshape(RZ,BinaryStates,NumStates);
end;
%---------------------
if printout
fprintf('-------- Z --------\n')
fprintf('%0.4f   %0.4f\n', RZ)
fprintf('-------------------\n')
end;
%---------------------
% Read bi
RBox = cell(NumStates,1);
if printout
   fprintf('-------- B --------\n')
end;
for i = 1:length(ind_classes)
    cls = ind_classes(i);
    biname = sprintf('%s-%d', 'bi', cls);
    [j, blockstart, blockend, statestart, stateend] = getvardata(vars, biname, 1);
    if blockstart > 0
        T_RBox = locBel(statestart:stateend);
        NumB = round(length(T_RBox) / BinaryStates);
        T_RBox = reshape(T_RBox',[BinaryStates, NumB])';
        if printout
            fprintf('%0.4f   %0.4f   %d\n', [T_RBox'; repmat(cls, [NumB, 1])'])
        end;
        
        cls = geticlass(classes, cls);
        RBox{cls} = T_RBox;
    end;
end
if printout
   fprintf('-------------------\n')
end;
%---------------------

%---------------------
% Read scenes
RScene = [];
varname = 'scene';

[j, blockstart, blockend, statestart, stateend] = getvardata(vars, varname, 1);
if blockstart > 0
    RScene = locBel(statestart:stateend);
    if printout
         fprintf('%0.4f\n', RScene)
    end;
end;
%---------------------

save(outfile,'RPixel','RSeg','RZ','RBox', 'RScene');